define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "ไตรมาสนี้",
	"field-quarter-short-relative+1": "ไตรมาสหน้า",
	"field-tue-relative+-1": "อังคารที่แล้ว",
	"field-year": "ปี",
	"dateFormatItem-Hm": "HH:mm",
	"field-wed-relative+0": "พุธนี้",
	"field-wed-relative+1": "พุธหน้า",
	"dateFormatItem-ms": "mm:ss",
	"field-minute": "นาที",
	"field-month-narrow-relative+-1": "เดือนที่แล้ว",
	"field-tue-narrow-relative+0": "อังคารนี้",
	"field-tue-narrow-relative+1": "อังคารหน้า",
	"field-day-short-relative+-1": "เมื่อวาน",
	"field-thu-short-relative+0": "พฤหัสนี้",
	"dateTimeFormat-short": "{1} {0}",
	"field-day-relative+0": "วันนี้",
	"field-day-short-relative+-2": "เมื่อวานซืน",
	"field-thu-short-relative+1": "พฤหัสหน้า",
	"field-day-relative+1": "พรุ่งนี้",
	"field-week-narrow-relative+0": "สัปดาห์นี้",
	"field-day-relative+2": "มะรืนนี้",
	"field-week-narrow-relative+1": "สัปดาห์หน้า",
	"field-wed-narrow-relative+-1": "พุธที่แล้ว",
	"field-year-narrow": "ปี",
	"field-era-short": "สมัย",
	"field-year-narrow-relative+0": "ปีนี้",
	"field-tue-relative+0": "อังคารนี้",
	"field-year-narrow-relative+1": "ปีหน้า",
	"field-tue-relative+1": "อังคารหน้า",
	"field-weekdayOfMonth": "วันของเดือน",
	"field-second-short": "วิ",
	"dateFormatItem-MMMd": "d MMM",
	"field-weekdayOfMonth-narrow": "วันของเดือน",
	"field-week-relative+0": "สัปดาห์นี้",
	"field-month-relative+0": "เดือนนี้",
	"field-week-relative+1": "สัปดาห์หน้า",
	"field-month-relative+1": "เดือนหน้า",
	"field-sun-narrow-relative+0": "วันอาทิตย์นี้",
	"field-mon-short-relative+0": "จันทร์นี้",
	"field-sun-narrow-relative+1": "วันอาทิตย์หน้า",
	"field-mon-short-relative+1": "จันทร์หน้า",
	"field-second-relative+0": "ขณะนี้",
	"dateFormatItem-yyyyQQQ": "QQQ G y",
	"field-weekOfMonth": "สัปดาห์ของเดือน",
	"field-month-short": "เดือน",
	"dateFormatItem-GyMMMEd": "E d MMM G y",
	"dateFormatItem-yyyyMd": "d/M/GGGGG y",
	"field-day": "วัน",
	"field-dayOfYear-short": "วันของปี",
	"field-year-relative+-1": "ปีที่แล้ว",
	"field-sat-short-relative+-1": "เสาร์ที่แล้ว",
	"field-hour-relative+0": "ชั่วโมงนี้",
	"dateFormatItem-yyyyMEd": "E d/M/GGGGG y",
	"field-wed-relative+-1": "พุธที่แล้ว",
	"dateTimeFormat-medium": "{1} {0}",
	"field-sat-narrow-relative+-1": "เสาร์ที่แล้ว",
	"field-second": "วินาที",
	"dateFormat-long": "d MMMM ปีG y",
	"dateFormatItem-GyMMMd": "d MMM G y",
	"field-quarter": "ไตรมาส",
	"field-week-short": "สัปดาห์",
	"field-day-narrow-relative+0": "วันนี้",
	"field-day-narrow-relative+1": "พรุ่งนี้",
	"field-day-narrow-relative+2": "มะรืนนี้",
	"field-tue-short-relative+0": "อังคารนี้",
	"field-tue-short-relative+1": "อังคารหน้า",
	"field-month-short-relative+-1": "เดือนที่แล้ว",
	"field-mon-relative+-1": "จันทร์ที่แล้ว",
	"dateFormatItem-GyMMM": "MMM G y",
	"field-month": "เดือน",
	"field-day-narrow": "วัน",
	"dateFormatItem-MMM": "LLL",
	"field-dayperiod": "ช่วงวัน",
	"field-sat-short-relative+0": "เสาร์นี้",
	"field-sat-short-relative+1": "เสาร์หน้า",
	"dateFormat-medium": "d MMM G y",
	"eraAbbr": [
		"ทะอิกะ (645–650)",
		"ฮะกุชิ (650–671)",
		"ฮากุโฮ (672–686)",
		"ชุโช (686–701)",
		"ทะอิโฮ (701–704)",
		"เคอุง (704–708)",
		"วะโด (708–715)",
		"เรกิ (715–717)",
		"โยโร (717–724)",
		"จิงกิ (724–729)",
		"เท็มเพียว (729–749)",
		"เท็มเพียว-คัมโป (749-749)",
		"เท็มเพียว-โชโฮ (749-757)",
		"เท็มเพียว-โฮจิ (757-765)",
		"เท็มเพียว-จิงโงะ (765-767)",
		"จิงโงะ-เคอุง (767-770)",
		"โฮกิ (770–780)",
		"เท็นโอ (781–782)",
		"เอ็นเรียะกุ (782–806)",
		"ดะอิโด (806–810)",
		"โคนิง (810–824)",
		"เท็นโช (824–834)",
		"โชวะ (834–848)",
		"คะโจ (848–851)",
		"นินจุ (851–854)",
		"ซะอิโกะ (854–857)",
		"เท็นนัง (857–859)",
		"โจงัง (859–877)",
		"เก็งเก (877–885)",
		"นินนะ (885–889)",
		"คัมเพียว (889–898)",
		"โชตะอิ (898–901)",
		"เอ็งงิ (901–923)",
		"เอ็นโช (923–931)",
		"โชเฮ (931–938)",
		"เท็งเงียว (938–947)",
		"เท็นเรียะกุ (947–957)",
		"เท็นโตะกุ (957–961)",
		"โอวะ (961–964)",
		"โคโฮ (964–968)",
		"อันนะ (968–970)",
		"เท็นโระกุ (970–973)",
		"เท็นเอ็ง (973–976)",
		"โจเง็ง (976–978)",
		"เท็งเง็ง (978–983)",
		"เอกัง (983–985)",
		"คันนะ (985–987)",
		"เอเอ็ง (987–989)",
		"เอโซ (989–990)",
		"โชเรียะกุ (990–995)",
		"โชโตะกุ (995–999)",
		"โชโฮ (999–1004)",
		"คันโก (1004–1012)",
		"โชวะ (1012–1017)",
		"คันนิง (1017–1021)",
		"จิอัง (1021–1024)",
		"มันจุ (1024–1028)",
		"โชเง็ง (1028–1037)",
		"โชเรียะกุ (1037–1040)",
		"โชคีว (1040–1044)",
		"คันโตะกุ (1044–1046)",
		"เอโช (1046–1053)",
		"เท็งงิ (1053–1058)",
		"โคเฮ (1058–1065)",
		"จิเรียะกุ (1065–1069)",
		"เอ็งคีว (1069–1074)",
		"โชโฮ (1074–1077)",
		"โชเรียะกุ (1077–1081)",
		"เอโฮะ (1081–1084)",
		"โอโตะกุ (1084–1087)",
		"คันจิ (1087–1094)",
		"คะโฮะ (1094–1096)",
		"เอโช (1096–1097)",
		"โชโตะกุ (1097–1099)",
		"โควะ (1099–1104)",
		"โชจิ (1104–1106)",
		"คะโช (1106–1108)",
		"เท็นนิง (1108–1110)",
		"เท็นเอ (1110–1113)",
		"เอกีว (1113–1118)",
		"เก็นเอ (1118–1120)",
		"โฮะอัง (1120–1124)",
		"เท็นจิ (1124–1126)",
		"ดะอิจิ (1126–1131)",
		"เท็นโช (1131–1132)",
		"โชโช (1132–1135)",
		"โฮะเอ็ง (1135–1141)",
		"เอจิ (1141–1142)",
		"โคจิ (1142–1144)",
		"เท็นโย (1144–1145)",
		"คีวอัง (1145–1151)",
		"นิมเป (1151–1154)",
		"คีวจุ (1154–1156)",
		"โฮะเง็ง (1156–1159)",
		"เฮจิ (1159–1160)",
		"เอเรียะกุ (1160–1161)",
		"โอโฮ (1161–1163)",
		"โชกัง (1163–1165)",
		"เอมัง (1165–1166)",
		"นินอัง (1166–1169)",
		"คะโอ (1169–1171)",
		"โชอัง (1171–1175)",
		"อังเง็ง (1175–1177)",
		"จิโช (1177–1181)",
		"โยวะ (1181–1182)",
		"จุเอ (1182–1184)",
		"เก็นเรียะกุ (1184–1185)",
		"บุนจิ (1185–1190)",
		"เค็งกีว (1190–1199)",
		"โชจิ (1199–1201)",
		"เค็นนิง (1201–1204)",
		"เก็งกีว (1204–1206)",
		"เค็นเอ (1206–1207)",
		"โชเก็ง (1207–1211)",
		"เค็นเรียะกุ (1211–1213)",
		"เค็มโป (1213–1219)",
		"โชกีว (1219–1222)",
		"โจโอ (1222–1224)",
		"เก็นนิง (1224–1225)",
		"คะโระกุ (1225–1227)",
		"อันเต (1227–1229)",
		"คังกิ (1229–1232)",
		"โจเอ (1232–1233)",
		"เท็มปุกุ (1233–1234)",
		"บุนเรียะกุ (1234–1235)",
		"คะเต (1235–1238)",
		"เรียะกุนิง (1238–1239)",
		"เอ็นโอ (1239–1240)",
		"นินจิ (1240–1243)",
		"คังเง็ง (1243–1247)",
		"โฮจิ (1247–1249)",
		"เค็นโช (1249–1256)",
		"โคเง็ง (1256–1257)",
		"โชกะ (1257–1259)",
		"โชเง็ง (1259–1260)",
		"บุนโอ (1260–1261)",
		"โคโช (1261–1264)",
		"บุนเอ (1264–1275)",
		"เค็นจิ (1275–1278)",
		"โคอัง (1278–1288)",
		"โชโอ (1288–1293)",
		"เอนิง (1293–1299)",
		"โชอัง (1299–1302)",
		"เค็งเง็ง (1302–1303)",
		"คะเง็ง (1303–1306)",
		"โทะกุจิ (1306–1308)",
		"เอ็งเก (1308–1311)",
		"โอโช (1311–1312)",
		"โชวะ (1312–1317)",
		"บุมโป (1317–1319)",
		"เก็นโอ (1319–1321)",
		"เก็งเกียว (1321–1324)",
		"โชชู (1324–1326)",
		"คะเระกิ (1326–1329)",
		"เก็นโตะกุ (1329–1331)",
		"เก็งโก (1331–1334)",
		"เค็มมุ (1334–1336)",
		"เอ็งเง็ง (1336–1340)",
		"โคโกะกุ (1340–1346)",
		"โชเฮ (1346–1370)",
		"เค็นโตะกุ (1370–1372)",
		"บุนชู (1372–1375)",
		"เท็นจุ (1375–1379)",
		"โคเรียะกุ (1379–1381)",
		"โควะ (1381–1384)",
		"เก็นชู (1384–1392)",
		"เมโตะกุ (1384–1387)",
		"คะเค (1387–1389)",
		"โคโอ (1389–1390)",
		"เมโตะกุ (1390–1394)",
		"โอเอ (1394–1428)",
		"โชโช (1428–1429)",
		"เอเกียว (1429–1441)",
		"คะกิสึ (1441–1444)",
		"บุนอัง (1444–1449)",
		"โฮโตะกุ (1449–1452)",
		"เคียวโตะกุ (1452–1455)",
		"โคโช (1455–1457)",
		"โชโระกุ (1457–1460)",
		"คันโช (1460–1466)",
		"บุนโช (1466–1467)",
		"โอนิง (1467–1469)",
		"บุมเม (1469–1487)",
		"โชเกียว (1487–1489)",
		"เอ็นโตะกุ (1489–1492)",
		"เมโอ (1492–1501)",
		"บุงกิ (1501–1504)",
		"เอโช (1504–1521)",
		"ทะอิเอ (1521–1528)",
		"เคียวโระกุ (1528–1532)",
		"เท็มมน (1532–1555)",
		"โคจิ (1555–1558)",
		"เอโระกุ (1558–1570)",
		"เก็งกิ (1570–1573)",
		"เท็นโช (1573–1592)",
		"บุนโระกุ (1592–1596)",
		"เคโช (1596–1615)",
		"เก็งวะ (1615–1624)",
		"คันเอ (1624–1644)",
		"โชโฮ (1644–1648)",
		"เคอัง (1648–1652)",
		"โชโอ (1652–1655)",
		"เมเรียะกุ (1655–1658)",
		"มันจิ (1658–1661)",
		"คัมบุง (1661–1673)",
		"เอ็มโป (1673–1681)",
		"เท็นวะ (1681–1684)",
		"โจเกียว (1684–1688)",
		"เก็นโระกุ (1688–1704)",
		"โฮเอ (1704–1711)",
		"โชโตะกุ (1711–1716)",
		"เคียวโฮ (1716–1736)",
		"เก็มบุง (1736–1741)",
		"คัมโป (1741–1744)",
		"เอ็งเกียว (1744–1748)",
		"คันเอ็ง (1748–1751)",
		"โฮเรียะกุ (1751–1764)",
		"เมวะ (1764–1772)",
		"อันเอ (1772–1781)",
		"เท็มเม (1781–1789)",
		"คันเซ (1789–1801)",
		"เคียววะ (1801–1804)",
		"บุงกะ (1804–1818)",
		"บุนเซ (1818–1830)",
		"เท็มโป (1830–1844)",
		"โคกะ (1844–1848)",
		"คะเอ (1848–1854)",
		"อันเซ (1854–1860)",
		"มันเอ็ง (1860–1861)",
		"บุงกีว (1861–1864)",
		"เก็นจิ (1864–1865)",
		"เคโอ (1865–1868)",
		"เมจิ",
		"ทะอิโช",
		"โชวะ",
		"เฮเซ",
		"เรวะ"
	],
	"dateFormatItem-yyyyM": "M/GGGGG y",
	"field-second-narrow": "วิ",
	"field-mon-relative+0": "จันทร์นี้",
	"field-mon-relative+1": "จันทร์หน้า",
	"field-day-narrow-relative+-1": "เมื่อวาน",
	"field-year-short": "ปี",
	"field-day-narrow-relative+-2": "เมื่อวานซืน",
	"field-quarter-relative+-1": "ไตรมาสที่แล้ว",
	"dateFormatItem-yyyyMMMd": "d MMM G y",
	"field-dayperiod-narrow": "ช่วงวัน",
	"field-week-narrow-relative+-1": "สัปดาห์ที่แล้ว",
	"field-dayOfYear": "วันของปี",
	"field-sat-relative+-1": "เสาร์ที่แล้ว",
	"dateTimeFormat-long": "{1} {0}",
	"dateFormatItem-Md": "d/M",
	"field-hour": "ชั่วโมง",
	"dateFormat-full": "EEEEที่ d MMMM ปีGที่ y",
	"field-month-relative+-1": "เดือนที่แล้ว",
	"dateFormatItem-Hms": "HH:mm:ss",
	"field-quarter-short": "ไตรมาส",
	"field-sat-narrow-relative+0": "เสาร์นี้",
	"field-fri-relative+0": "ศุกร์นี้",
	"field-sat-narrow-relative+1": "เสาร์หน้า",
	"field-fri-relative+1": "ศุกร์หน้า",
	"field-month-narrow-relative+0": "เดือนนี้",
	"field-month-narrow-relative+1": "เดือนหน้า",
	"field-sun-short-relative+0": "วันอาทิตย์นี้",
	"field-sun-short-relative+1": "วันอาทิตย์หน้า",
	"field-week-relative+-1": "สัปดาห์ที่แล้ว",
	"field-quarter-short-relative+-1": "ไตรมาสที่แล้ว",
	"field-quarter-relative+0": "ไตรมาสนี้",
	"field-minute-relative+0": "นาทีนี้",
	"field-quarter-relative+1": "ไตรมาสหน้า",
	"field-wed-short-relative+-1": "พุธที่แล้ว",
	"dateFormat-short": "d/M/yy G",
	"field-year-narrow-relative+-1": "ปีที่แล้ว",
	"field-thu-short-relative+-1": "พฤหัสที่แล้ว",
	"dateFormatItem-yyyyMMMEd": "E d MMM G y",
	"field-mon-narrow-relative+-1": "จันทร์ที่แล้ว",
	"field-thu-narrow-relative+-1": "พฤหัสที่แล้ว",
	"dateFormatItem-H": "HH",
	"field-weekOfMonth-short": "สัปดาห์ของเดือน",
	"field-tue-narrow-relative+-1": "อังคารที่แล้ว",
	"dateFormatItem-yyyy": "G y",
	"dateFormatItem-M": "L",
	"field-wed-short-relative+0": "พุธนี้",
	"field-wed-short-relative+1": "พุธหน้า",
	"field-sun-relative+-1": "วันอาทิตย์ที่แล้ว",
	"dateTimeFormat-full": "{1} {0}",
	"dateFormatItem-hm": "h:mm a",
	"dateFormatItem-d": "d",
	"field-weekday": "วันของสัปดาห์",
	"field-day-short-relative+0": "วันนี้",
	"field-quarter-narrow-relative+0": "ไตรมาสนี้",
	"field-day-short-relative+1": "พรุ่งนี้",
	"field-sat-relative+0": "เสาร์นี้",
	"field-quarter-narrow-relative+1": "ไตรมาสหน้า",
	"dateFormatItem-h": "h a",
	"field-day-short-relative+2": "มะรืนนี้",
	"field-sat-relative+1": "เสาร์หน้า",
	"field-week-short-relative+0": "สัปดาห์นี้",
	"field-week-short-relative+1": "สัปดาห์หน้า",
	"field-dayOfYear-narrow": "วันของปี",
	"field-month-short-relative+0": "เดือนนี้",
	"field-month-short-relative+1": "เดือนหน้า",
	"field-weekdayOfMonth-short": "วันของเดือน",
	"dateFormatItem-MEd": "E, d/M",
	"field-zone-narrow": "เขตเวลา",
	"dateFormatItem-y": "G y",
	"field-thu-narrow-relative+0": "พฤหัสนี้",
	"field-sun-narrow-relative+-1": "วันอาทิตย์ที่แล้ว",
	"field-mon-short-relative+-1": "จันทร์ที่แล้ว",
	"field-thu-narrow-relative+1": "พฤหัสหน้า",
	"field-thu-relative+0": "พฤหัสนี้",
	"field-thu-relative+1": "พฤหัสหน้า",
	"dateFormatItem-hms": "h:mm:ss a",
	"field-fri-short-relative+-1": "ศุกร์ที่แล้ว",
	"field-thu-relative+-1": "พฤหัสที่แล้ว",
	"field-week": "สัปดาห์",
	"dateFormatItem-Ed": "E d",
	"field-wed-narrow-relative+0": "พุธนี้",
	"field-wed-narrow-relative+1": "พุธหน้า",
	"field-quarter-narrow-relative+-1": "ไตรมาสที่แล้ว",
	"field-year-short-relative+0": "ปีนี้",
	"dateFormatItem-yyyyMMM": "MMM G y",
	"field-dayperiod-short": "ช่วงวัน",
	"field-year-short-relative+1": "ปีหน้า",
	"field-fri-short-relative+0": "ศุกร์นี้",
	"field-fri-short-relative+1": "ศุกร์หน้า",
	"field-week-short-relative+-1": "สัปดาห์ที่แล้ว",
	"dateFormatItem-yyyyQQQQ": "QQQQ G y",
	"field-hour-short": "ชม.",
	"field-zone-short": "โซน",
	"field-month-narrow": "เดือน",
	"field-hour-narrow": "ชม.",
	"field-fri-narrow-relative+-1": "ศุกร์ที่แล้ว",
	"field-year-relative+0": "ปีนี้",
	"field-year-relative+1": "ปีหน้า",
	"field-era-narrow": "สมัย",
	"field-fri-relative+-1": "ศุกร์ที่แล้ว",
	"field-tue-short-relative+-1": "อังคารที่แล้ว",
	"field-minute-narrow": "นาที",
	"field-mon-narrow-relative+0": "จันทร์นี้",
	"field-mon-narrow-relative+1": "จันทร์หน้า",
	"field-year-short-relative+-1": "ปีที่แล้ว",
	"field-zone": "เขตเวลา",
	"dateFormatItem-MMMEd": "E d MMM",
	"field-weekOfMonth-narrow": "สัปดาห์ของเดือน",
	"field-weekday-narrow": "วันของสัปดาห์",
	"field-quarter-narrow": "ไตรมาส",
	"field-sun-short-relative+-1": "วันอาทิตย์ที่แล้ว",
	"field-day-relative+-1": "เมื่อวาน",
	"field-day-relative+-2": "เมื่อวานซืน",
	"field-weekday-short": "วันของสัปดาห์",
	"field-sun-relative+0": "วันอาทิตย์นี้",
	"field-sun-relative+1": "วันอาทิตย์หน้า",
	"dateFormatItem-Gy": "G y",
	"field-day-short": "วัน",
	"field-week-narrow": "สัปดาห์",
	"field-era": "สมัย",
	"field-fri-narrow-relative+0": "ศุกร์นี้",
	"field-fri-narrow-relative+1": "ศุกร์หน้า"
}
//end v1.x content
);